==> phpMinAdmin-1.7.0.zip: phpMinAdmin-1.7.0/lang/es.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Salida exitosa.',
	'Invalid credentials.' => 'Autenticación fallada.',
	'Server' => 'Servidor',
	'Username' => 'Usuario',
	'Password' => 'Contraseña',
	'Select database' => 'Seleccionar Base de datos',
	'Invalid database.' => 'Base de datos inválida.',
	'Create new database' => 'Nueva Base de datos',
	'Table has been dropped.' => 'Tabla eliminada.',
	'Table has been altered.' => 'Tabla modificada.',
	'Table has been created.' => 'Tabla creada.',
	'Alter table' => 'Modificar tabla',
	'Create table' => 'Crear tabla',
	'Table name' => 'Nombre de tabla',
	'engine' => 'motor',
	'collation' => 'collation',
	'Column name' => 'Nombre de columna',
	'Type' => 'Tipo',
	'Length' => 'Longitud',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto increment',
	'Options' => 'Opciones',
	'Save' => 'Guardar',
	'Drop' => 'Eliminar',
	'Database has been dropped.' => 'Base de datos eliminada.',
	'Database has been created.' => 'Base de datos creada.',
	'Database has been renamed.' => 'Base de datos renombrada.',
	'Database has been altered.' => 'Base de datos modificada.',
	'Alter database' => 'Modificar Base de datos',
	'Create database' => 'Crear Base de datos',
	'SQL command' => 'Comando SQL',
	'Dump' => 'Export',
	'Logout' => 'Logout',
	'database' => 'base de datos',
	'Use' => 'Uso',
	'No tables.' => 'No existen tablas.',
	'select' => 'registros',
	'Create new table' => 'Nueva tabla',
	'Item has been deleted.' => 'Registro eliminado.',
	'Item has been updated.' => 'Registro modificado.',
	'Item has been inserted.' => 'Registro insertado.',
	'Edit' => 'Modificar',
	'Insert' => 'Agregar',
	'Save and insert next' => 'Guardar e insertar otro',
	'Delete' => 'Eliminar',
	'Database' => 'Base de datos',
	'Routines' => 'Procedimientos',
	'Indexes has been altered.' => 'Indices modificados.',
	'Indexes' => 'Indices',
	'Alter indexes' => 'Modificar indices',
	'Add next' => 'Agregar',
	'Language' => 'Idioma',
	'Select' => 'Mostrar Registros',
	'New item' => 'Nuevo Registro',
	'Search' => 'Buscar',
	'Sort' => 'Ordenar',
	'DESC' => 'descendiente',
	'Limit' => 'Limit',
	'No rows.' => 'No hay filas.',
	'Action' => 'Acción',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Error in query' => 'Error en consulta',
	'Execute' => 'Ejecutar',
	'Table' => 'Tabla',
	'Foreign keys' => 'Claves foráneas',
	'Triggers' => 'Triggers',
	'View' => 'Vistas',
	'Unable to select the table' => 'No posible seleccionar la tabla',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Vuelva a enviar los datos del formulario.',
	'Comment' => 'Comentario',
	'Default values has been set.' => 'Valores por omisión establecidos.',
	'Default values' => 'Establecer valores por omisión',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Mostrar comentario de columnas',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'No hay comando a ejecutar.',
	'Unable to upload a file.' => 'No posible subir archivos.',
	'File upload' => 'Importar archivo',
	'File uploads are disabled.' => 'Importación de archivos deshablilitado.',
	'Routine has been called, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Call' => 'Llamar',
	'No MySQL extension' => 'No hay extension MySQL',
	'None of supported PHP extensions (%s) are available.' => 'Ninguna de las extensiones PHP soportadas (%s) está disponible.',
	'Sessions must be enabled.' => 'Deben estar habilitadas las sesiones.',
	'Session expired, please login again.' => 'Sesion expirada, favor loguéese de nuevo.',
	'Text length' => 'Longitud de texto',
	'Syntax highlighting' => 'Destacar Sintaxis',
	'Foreign key has been dropped.' => 'Clave foránea eliminada.',
	'Foreign key has been altered.' => 'Clave foránea modificada.',
	'Foreign key has been created.' => 'Clave foránea creada.',
	'Foreign key' => 'Clave foránea',
	'Target table' => 'Tabla destino',
	'Change' => 'Modificar',
	'Source' => 'Origen',
	'Target' => 'Destino',
	'Add column' => 'Agregar columna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Agregar clave foránea',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo de índice',
	'Column (length)' => 'Columna (longitud)',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista creada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Cear vista',
	'Name' => 'Nombre',
	'Process list' => 'Lista de procesos',
	'%d process(es) has been killed.' => array('%d proceso detenido.', '%d procesos detenidos.'),
	'Kill' => 'Detener',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Nombre de Parametro',
	'Database schema' => 'Esquema de base de datos',
	'Create procedure' => 'Crear procedimiento',
	'Create function' => 'Crear función',
	'Routine has been dropped.' => 'Procedimiento eliminado.',
	'Routine has been altered.' => 'Procedimiento modificado.',
	'Routine has been created.' => 'Procedimiento creado.',
	'Alter function' => 'Modificar Función',
	'Alter procedure' => 'Modificar procedimiento',
	'Return type' => 'Tipo de valor retornado',
	'Add trigger' => 'Agregar trigger',
	'Trigger has been dropped.' => 'Trigger eliminado.',
	'Trigger has been altered.' => 'Trigger modificado.',
	'Trigger has been created.' => 'Trigger creado.',
	'Alter trigger' => 'Modificar Trigger',
	'Create trigger' => 'Agregar Trigger',
	'Time' => 'Tiempo',
	'Event' => 'Evento',
	'%d row(s)' => array('%d fila', '%d filas'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Eliminar',
	'Are you sure?' => 'Está seguro?',
	'Privileges' => 'Privilegios',
	'Create user' => 'Crear Usuario',
	'User has been dropped.' => 'Usuario eliminado.',
	'User has been altered.' => 'Usuario modificado.',
	'User has been created.' => 'Usuario creado.',
	'Hashed' => 'Hash',
	'Column' => 'Columna',
	'Routine' => 'Rutina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Error during deleting' => 'Error durante el borrado',
	'%d item(s) have been deleted.' => array('%d item eliminado.', '%d itemes eliminados.'),
	'all' => 'todos',
	'Delete selected' => 'Eliminar seleccionados',
	'MySQL version: %s through PHP extension %s' => 'Versión MySQL: %s a través de extensión PHP %s',
	'around %d row(s)' => array('acaso %d fila', 'acaso %d filas'),
	'Logged as: %s' => 'Logeado como: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST data demasiado grande. Reduzca el tamaño o aumente la directiva de configuración "post_max_size".',
	'Move up' => 'Mover arriba',
	'Move down' => 'Mover abajo',
	'Export' => 'Exportar',
	'skip' => 'ignorar',
	'Tables' => 'Tablas',
	'Structure' => 'Estructura',
	'Data' => 'Datos',
	'Output' => 'Salida',
	'open' => 'mostrar',
	'save' => 'guardar',
	'Format' => 'Formato',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'Functions' => 'Funciones',
	'Aggregation' => 'Agregaciones',
	'Truncate result' => 'Limitar resultado',
	'Export selected' => 'Exportar seleccionados',
	'Export result' => 'Exportar resultado',
);

==> phpMinAdmin-1.9.1.zip: phpMinAdmin-1.9.1/lang/es.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Salida exitosa.',
	'Invalid credentials.' => 'Autenticación fallada.',
	'Server' => 'Servidor',
	'Username' => 'Usuario',
	'Password' => 'Contraseña',
	'Select database' => 'Seleccionar Base de datos',
	'Invalid database.' => 'Base de datos inválida.',
	'Create new database' => 'Nueva Base de datos',
	'Table has been dropped.' => 'Tabla eliminada.',
	'Table has been altered.' => 'Tabla modificada.',
	'Table has been created.' => 'Tabla creada.',
	'Alter table' => 'Modificar tabla',
	'Create table' => 'Crear tabla',
	'Table name' => 'Nombre de tabla',
	'engine' => 'motor',
	'collation' => 'collation',
	'Column name' => 'Nombre de columna',
	'Type' => 'Tipo',
	'Length' => 'Longitud',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto increment',
	'Options' => 'Opciones',
	'Save' => 'Guardar',
	'Drop' => 'Eliminar',
	'Database has been dropped.' => 'Base de datos eliminada.',
	'Database has been created.' => 'Base de datos creada.',
	'Database has been renamed.' => 'Base de datos renombrada.',
	'Database has been altered.' => 'Base de datos modificada.',
	'Alter database' => 'Modificar Base de datos',
	'Create database' => 'Crear Base de datos',
	'SQL command' => 'Comando SQL',
	'Dump' => 'Export',
	'Logout' => 'Logout',
	'database' => 'base de datos',
	'Use' => 'Uso',
	'No tables.' => 'No existen tablas.',
	'select' => 'registros',
	'Create new table' => 'Nueva tabla',
	'Item has been deleted.' => 'Registro eliminado.',
	'Item has been updated.' => 'Registro modificado.',
	'Item has been inserted.' => 'Registro insertado.',
	'Edit' => 'Modificar',
	'Insert' => 'Agregar',
	'Save and insert next' => 'Guardar e insertar otro',
	'Delete' => 'Eliminar',
	'Database' => 'Base de datos',
	'Routines' => 'Procedimientos',
	'Indexes has been altered.' => 'Indices modificados.',
	'Indexes' => 'Indices',
	'Alter indexes' => 'Modificar indices',
	'Add next' => 'Agregar',
	'Language' => 'Idioma',
	'Select' => 'Mostrar Registros',
	'New item' => 'Nuevo Registro',
	'Search' => 'Buscar',
	'Sort' => 'Ordenar',
	'DESC' => 'descendiente',
	'Limit' => 'Limit',
	'No rows.' => 'No hay filas.',
	'Action' => 'Acción',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Error in query' => 'Error en consulta',
	'Execute' => 'Ejecutar',
	'Table' => 'Tabla',
	'Foreign keys' => 'Claves foráneas',
	'Triggers' => 'Triggers',
	'View' => 'Vistas',
	'Unable to select the table' => 'No posible seleccionar la tabla',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Vuelva a enviar los datos del formulario.',
	'Comment' => 'Comentario',
	'Default values has been set.' => 'Valores por omisión establecidos.',
	'Default values' => 'Establecer valores por omisión',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Mostrar comentario de columnas',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'No hay comando a ejecutar.',
	'Unable to upload a file.' => 'No posible subir archivos.',
	'File upload' => 'Importar archivo',
	'File uploads are disabled.' => 'Importación de archivos deshablilitado.',
	'Routine has been called, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Call' => 'Llamar',
	'No MySQL extension' => 'No hay extension MySQL',
	'None of supported PHP extensions (%s) are available.' => 'Ninguna de las extensiones PHP soportadas (%s) está disponible.',
	'Sessions must be enabled.' => 'Deben estar habilitadas las sesiones.',
	'Session expired, please login again.' => 'Sesion expirada, favor loguéese de nuevo.',
	'Text length' => 'Longitud de texto',
	'Syntax highlighting' => 'Destacar Sintaxis',
	'Foreign key has been dropped.' => 'Clave foránea eliminada.',
	'Foreign key has been altered.' => 'Clave foránea modificada.',
	'Foreign key has been created.' => 'Clave foránea creada.',
	'Foreign key' => 'Clave foránea',
	'Target table' => 'Tabla destino',
	'Change' => 'Modificar',
	'Source' => 'Origen',
	'Target' => 'Destino',
	'Add column' => 'Agregar columna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Agregar clave foránea',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo de índice',
	'Column (length)' => 'Columna (longitud)',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista creada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Cear vista',
	'Name' => 'Nombre',
	'Process list' => 'Lista de procesos',
	'%d process(es) has been killed.' => array('%d proceso detenido.', '%d procesos detenidos.'),
	'Kill' => 'Detener',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Nombre de Parametro',
	'Database schema' => 'Esquema de base de datos',
	'Create procedure' => 'Crear procedimiento',
	'Create function' => 'Crear función',
	'Routine has been dropped.' => 'Procedimiento eliminado.',
	'Routine has been altered.' => 'Procedimiento modificado.',
	'Routine has been created.' => 'Procedimiento creado.',
	'Alter function' => 'Modificar Función',
	'Alter procedure' => 'Modificar procedimiento',
	'Return type' => 'Tipo de valor retornado',
	'Add trigger' => 'Agregar trigger',
	'Trigger has been dropped.' => 'Trigger eliminado.',
	'Trigger has been altered.' => 'Trigger modificado.',
	'Trigger has been created.' => 'Trigger creado.',
	'Alter trigger' => 'Modificar Trigger',
	'Create trigger' => 'Agregar Trigger',
	'Time' => 'Tiempo',
	'Event' => 'Evento',
	'MySQL version: %s through PHP extension %s' => 'Versión MySQL: %s a través de extensión PHP %s',
	'%d row(s)' => array('%d fila', '%d filas'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Eliminar',
	'Are you sure?' => 'Está seguro?',
	'Privileges' => 'Privilegios',
	'Create user' => 'Crear Usuario',
	'User has been dropped.' => 'Usuario eliminado.',
	'User has been altered.' => 'Usuario modificado.',
	'User has been created.' => 'Usuario creado.',
	'Hashed' => 'Hash',
	'Column' => 'Columna',
	'Routine' => 'Rutina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST data demasiado grande. Reduzca el tamaño o aumente la directiva de configuración "post_max_size".',
	'Logged as: %s' => 'Logeado como: %s',
	'Move up' => 'Mover arriba',
	'Move down' => 'Mover abajo',
	'Functions' => 'Funciones',
	'Aggregation' => 'Agregaciones',
	'Export' => 'Exportar',
	'Output' => 'Salida',
	'open' => 'mostrar',
	'save' => 'guardar',
	'Format' => 'Formato',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'skip' => 'ignorar',
	'Tables' => 'Tablas',
	'Structure' => 'Estructura',
	'Data' => 'Datos',
	'Event has been dropped.' => 'Evento eliminado.',
	'Event has been altered.' => 'Evento modificado.',
	'Event has been created.' => 'Evento creado.',
	'Alter event' => 'Modificar Evento',
	'Create event' => 'Crear Evento',
	'At given time' => 'A hora determinada',
	'Every' => 'Cada',
	'Events' => 'Eventos',
	'Schedule' => 'Agendamiento',
	'Start' => 'Inicio',
	'End' => 'Fin',
	'Status' => 'Estado',
	'On completion preserve' => 'Al completar preservar',
	'Tables and views' => 'Tablas y vistas',
	'Data Length' => 'Longitud de datos',
	'Index Length' => 'Longitud de índice',
	'Data Free' => 'Espacio libre',
	'Collation' => 'Collation',
	'Analyze' => 'Analizar',
	'Optimize' => 'Optimizar',
	'Check' => 'Comprobar',
	'Repair' => 'Reparar',
	'Truncate' => 'Vaciar',
	'Tables have been truncated.' => 'Tablas vaciadas (truncate).',
	'Rows' => 'Filas',
	',' => ' ',
	'Tables have been moved.' => 'Se movieron las tablas.',
	'Move to other database' => 'mover a otra base de datos',
	'Move' => 'Mover',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Guardar y continuar editando',
	'clone' => 'clonar',
	'original' => 'original',
	'Tables have been dropped.' => 'Las tablas fueron eliminados.',
	'%d item(s) have been affected.' => array('%d item afectado.', '%d itemes afectados.'),
	'whole result' => 'resultado completo',
	'Clone' => 'Clonar',
);
